pub enum Pixels {
Rgb8(Vec<u8>),
Rgba8(Vec<u8>),
}Expand description
The result of attempting to extract RGB8 data from a Pixmap.
Variants
Rgb8(Vec<u8>)
Three bytes per pixel in red, green, blue order.
Rgba8(Vec<u8>)
Four bytes per pixel in red, green, blue, alpha order.