#[non_exhaustive]pub enum WebGlError {
Render(RenderError),
ContextUnavailable,
OperationFailed {
operation: WebGlOperation,
message: Option<String>,
},
TooManyInstances,
ResourceTextureTooLarge {
width: u32,
height: u32,
max_dimension: u32,
},
IncompatibleContext(IncompatibleContextReason),
}Expand description
Errors produced by the WebGL backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Render(RenderError)
Rendering failed for a certain reason.
A WebGL2 context could not be created for the canvas.
OperationFailed
A WebGL operation failed.
Fields

operation: WebGlOperationThe failed operation.
TooManyInstances
A render pass contains too many instances for WebGL.
ResourceTextureTooLarge
A resource texture allocation exceeds the supported texture dimensions.
Fields
IncompatibleContext(IncompatibleContextReason)
The WebGL context is incompatible with the renderer.