pub struct PixelMetadata {
pub may_have_transparency: bool,
pub alpha_type: ImageAlphaType,
}Expand description
Metadata about the pixels of an image.
Fields
may_have_transparency: boolWhether the pixels may be non-opaque.
If unsure, always set this to true. Setting this to false is a strong guarantee that
every pixel in the image is guaranteed to be opaque. Setting this to false mistakenly
can lead to wrong rendering.
alpha_type: ImageAlphaTypeHow the alpha channel is represented.
Implementations
Sourceimpl PixelMetadata
impl PixelMetadata
Sourcepub const fn new(
alpha_type: ImageAlphaType,
may_have_transparency: bool,
) -> PixelMetadata
pub const fn new( alpha_type: ImageAlphaType, may_have_transparency: bool, ) -> PixelMetadata
Create a new pixel metadata description.